@@ -133,7 +133,7 @@ void Command::fromXML(Document* d, QXmlStreamReader& stream, Command* C)
     if (stream.attributes().hasAttribute("oldCreated"))
         C->oldCreated = stream.attributes().value("oldCreated").toString();
     if (stream.attributes().hasAttribute("undone"))
-        C->isUndone = (stream.attributes().value("undone") == "true" ? true : false);
+        C->isUndone = (stream.attributes().value("undone") == QStringLiteral("true") ? true : false);
     if (stream.attributes().hasAttribute("description"))
         C->description = stream.attributes().value("description").toString();
     C->mainFeature = F;
@@ -246,72 +246,72 @@ CommandList* CommandList::fromXML(Document* d, QXmlStreamReader& stream)
 {
     CommandList* l = new CommandList();
     l->setId(stream.attributes().value("xml:id").toString());
-    l->isReversed = (stream.attributes().value("reversed") == "true");
+    l->isReversed = (stream.attributes().value("reversed") == QStringLiteral("true"));
     if (stream.attributes().hasAttribute("description"))
         l->description = stream.attributes().value("description").toString();
     if (stream.attributes().hasAttribute("feature")) {
-        if (stream.attributes().value("featureclass") == "Node") {
+        if (stream.attributes().value("featureclass") == QStringLiteral("Node")) {
             l->mainFeature = (Feature*) Feature::getNodeOrCreatePlaceHolder(d, (Layer *) d->getDirtyOrOriginLayer(), IFeature::FId(IFeature::Point, stream.attributes().value("feature").toString().toLongLong()));
         } else
-        if (stream.attributes().value("featureclass") == "Way") {
+        if (stream.attributes().value("featureclass") == QStringLiteral("Way")) {
             l->mainFeature = (Feature*) Feature::getWayOrCreatePlaceHolder(d, (Layer *) d->getDirtyOrOriginLayer(), IFeature::FId(IFeature::LineString, stream.attributes().value("feature").toString().toLongLong()));
         } else
-        if (stream.attributes().value("featureclass") == "Relation") {
+        if (stream.attributes().value("featureclass") == QStringLiteral("Relation")) {
             l->mainFeature = (Feature*) Feature::getRelationOrCreatePlaceHolder(d, (Layer *) d->getDirtyOrOriginLayer(), IFeature::FId(IFeature::OsmRelation, stream.attributes().value("feature").toString().toLongLong()));
         }
     }
 
     stream.readNext();
     while(!stream.atEnd() && !stream.isEndElement()) {
-        if (stream.name() == "AddFeatureCommand") {
+        if (stream.name() == QStringLiteral("AddFeatureCommand")) {
             AddFeatureCommand* C = AddFeatureCommand::fromXML(d, stream);
             if (C)
                 l->add(C);
-        } else if (stream.name() == "MoveTrackPointCommand") {
+        } else if (stream.name() == QStringLiteral("MoveTrackPointCommand")) {
             MoveNodeCommand* C = MoveNodeCommand::fromXML(d, stream);
             if (C)
                 l->add(C);
-        } else if (stream.name() == "RelationAddFeatureCommand") {
+        } else if (stream.name() == QStringLiteral("RelationAddFeatureCommand")) {
             RelationAddFeatureCommand* C = RelationAddFeatureCommand::fromXML(d, stream);
             if (C)
                 l->add(C);
-        } else if (stream.name() == "RelationRemoveFeatureCommand") {
+        } else if (stream.name() == QStringLiteral("RelationRemoveFeatureCommand")) {
             RelationRemoveFeatureCommand* C = RelationRemoveFeatureCommand::fromXML(d, stream);
             if (C)
                 l->add(C);
-        } else if (stream.name() == "RemoveFeatureCommand") {
+        } else if (stream.name() == QStringLiteral("RemoveFeatureCommand")) {
             RemoveFeatureCommand* C = RemoveFeatureCommand::fromXML(d, stream);
             if (C)
                 l->add(C);
-        } else if (stream.name() == "RoadAddTrackPointCommand") {
+        } else if (stream.name() == QStringLiteral("RoadAddTrackPointCommand")) {
             WayAddNodeCommand* C = WayAddNodeCommand::fromXML(d, stream);
             if (C)
                 l->add(C);
-        } else if (stream.name() == "RoadRemoveTrackPointCommand") {
+        } else if (stream.name() == QStringLiteral("RoadRemoveTrackPointCommand")) {
             WayRemoveNodeCommand* C = WayRemoveNodeCommand::fromXML(d, stream);
             if (C)
                 l->add(C);
-        } else if (stream.name() == "TrackSegmentAddTrackPointCommand") {
+        } else if (stream.name() == QStringLiteral("TrackSegmentAddTrackPointCommand")) {
             TrackSegmentAddNodeCommand* C = TrackSegmentAddNodeCommand::fromXML(d, stream);
             if (C)
                 l->add(C);
-        } else if (stream.name() == "TrackSegmentRemoveTrackPointCommand") {
+        } else if (stream.name() == QStringLiteral("TrackSegmentRemoveTrackPointCommand")) {
             TrackSegmentRemoveNodeCommand* C = TrackSegmentRemoveNodeCommand::fromXML(d, stream);
             if (C)
                 l->add(C);
-        } else if (stream.name() == "ClearTagCommand") {
+        } else if (stream.name() == QStringLiteral("ClearTagCommand")) {
             ClearTagCommand* C = ClearTagCommand::fromXML(d, stream);
             if (C)
                 l->add(C);
-        } else if (stream.name() == "ClearTagsCommand") {
+        } else if (stream.name() == QStringLiteral("ClearTagsCommand")) {
             ClearTagsCommand* C = ClearTagsCommand::fromXML(d, stream);
             if (C)
                 l->add(C);
-        } else if (stream.name() == "SetTagCommand") {
+        } else if (stream.name() == QStringLiteral("SetTagCommand")) {
             SetTagCommand* C = SetTagCommand::fromXML(d, stream);
             if (C)
                 l->add(C);
-        } else if (stream.name() == "CommandList") {
+        } else if (stream.name() == QStringLiteral("CommandList")) {
             l->add(CommandList::fromXML(d, stream));
         } else if (!stream.isWhitespace()) {
                 qDebug() << "CList: logic error:" << stream.name() << ":" << stream.tokenType() << "(" << stream.lineNumber() << ")";
@@ -466,79 +466,79 @@ CommandHistory* CommandHistory::fromXML(Document* d, QXmlStreamReader& stream, Q
 
     stream.readNext();
     while(!stream.atEnd() && !stream.isEndElement()) {
-        if (stream.name() == "CommandList") {
+        if (stream.name() == QStringLiteral("CommandList")) {
             CommandList* l = CommandList::fromXML(d, stream);
             if (l)
                 h->add(l);
             else
                 OK = false;
-        } else if (stream.name() == "AddFeatureCommand") {
+        } else if (stream.name() == QStringLiteral("AddFeatureCommand")) {
             AddFeatureCommand* C = AddFeatureCommand::fromXML(d, stream);
             if (C)
                 h->add(C);
             else
                 OK = false;
-        } else if (stream.name() == "MoveTrackPointCommand") {
+        } else if (stream.name() == QStringLiteral("MoveTrackPointCommand")) {
             MoveNodeCommand* C = MoveNodeCommand::fromXML(d, stream);
             if (C)
                 h->add(C);
             else
                 OK = false;
-        } else if (stream.name() == "RelationAddFeatureCommand") {
+        } else if (stream.name() == QStringLiteral("RelationAddFeatureCommand")) {
             RelationAddFeatureCommand* C = RelationAddFeatureCommand::fromXML(d, stream);
             if (C)
                 h->add(C);
             else
                 OK = false;
-        } else if (stream.name() == "RelationRemoveFeatureCommand") {
+        } else if (stream.name() == QStringLiteral("RelationRemoveFeatureCommand")) {
             RelationRemoveFeatureCommand* C = RelationRemoveFeatureCommand::fromXML(d, stream);
             if (C)
                 h->add(C);
             else
                 OK = false;
-        } else if (stream.name() == "RemoveFeatureCommand") {
+        } else if (stream.name() == QStringLiteral("RemoveFeatureCommand")) {
             RemoveFeatureCommand* C = RemoveFeatureCommand::fromXML(d, stream);
             if (C)
                 h->add(C);
             else
                 OK = false;
-        } else if (stream.name() == "RoadAddTrackPointCommand") {
+        } else if (stream.name() == QStringLiteral("RoadAddTrackPointCommand")) {
             WayAddNodeCommand* C = WayAddNodeCommand::fromXML(d, stream);
             if (C)
                 h->add(C);
             else
                 OK = false;
-        } else if (stream.name() == "RoadRemoveTrackPointCommand") {
+        } else if (stream.name() == QStringLiteral("RoadRemoveTrackPointCommand")) {
             WayRemoveNodeCommand* C = WayRemoveNodeCommand::fromXML(d, stream);
             if (C)
                 h->add(C);
             else
                 OK = false;
-        } else if (stream.name() == "TrackSegmentAddTrackPointCommand") {
+        } else if (stream.name() == QStringLiteral("TrackSegmentAddTrackPointCommand")) {
             TrackSegmentAddNodeCommand* C = TrackSegmentAddNodeCommand::fromXML(d, stream);
             if (C)
                 h->add(C);
             else
                 OK = false;
-        } else if (stream.name() == "TrackSegmentRemoveTrackPointCommand") {
+        } else if (stream.name() == QStringLiteral("TrackSegmentRemoveTrackPointCommand")) {
             TrackSegmentRemoveNodeCommand* C = TrackSegmentRemoveNodeCommand::fromXML(d, stream);
             if (C)
                 h->add(C);
             else
                 OK = false;
-        } else if (stream.name() == "ClearTagCommand") {
+        } else if (stream.name() == QStringLiteral("ClearTagCommand")) {
             ClearTagCommand* C = ClearTagCommand::fromXML(d, stream);
             if (C)
                 h->add(C);
             else
                 OK = false;
-        } else if (stream.name() == "ClearTagsCommand") {
+        } else if (stream.name() == QStringLiteral("ClearTagsCommand")) {
             ClearTagsCommand* C = ClearTagsCommand::fromXML(d, stream);
             if (C)
                 h->add(C);
             else
                 OK = false;
-        } else if (stream.name() == "SetTagCommand") {
+        } else if (stream.name() == QStringLiteral("SetTagCommand")) {
             SetTagCommand* C = SetTagCommand::fromXML(d, stream);
             if (C)
                 h->add(C);
