@@ -9,7 +9,7 @@
 #include <QtGui/QPainter>
 #include <QProgressDialog>
 
-#define TEST_RFLAGS(x) theView->renderOptions().options.testFlag(x)
+#define TEST_RFLAGS_NODE(x) theView->renderOptions().options.testFlag(x)
 
 Node::Node(const Coord& aCoord)
     : Feature()
@@ -163,7 +163,7 @@ const CoordBox& Node::boundingBox(bool) const
 
 void Node::drawSimple(QPainter &P, MapView *theView)
 {
-//    if (!M_PREFS->getWireframeView() && !TEST_RFLAGS(RendererOptions::Interacting))
+//    if (!M_PREFS->getWireframeView() && !TEST_RFLAGS_NODE(RendererOptions::Interacting))
 //        return;
 
     if (! ((isReadonly() || !isSelectable(theView->pixelPerM(), theView->renderOptions())) && (!isPOI() && !isWaypoint())))
@@ -354,7 +354,7 @@ Node * Node::fromXML(Document* d, Layer* L, QXmlStreamReader& stream)
 
     stream.readNext();
     while(!stream.atEnd() && !stream.isEndElement()) {
-        if (stream.name() == "tag") {
+        if (stream.name() == QStringLiteral("tag")) {
             Pt->setTag(stream.attributes().value("k").toString(), stream.attributes().value("v").toString());
             stream.readNext();
         }
@@ -482,12 +482,12 @@ void TrackNode::setElevation(qreal aElevation)
 
 const QDateTime& TrackNode::time() const
 {
-    return QDateTime::fromTime_t(Time);
+    return QDateTime::fromSecsSinceEpoch(Time);
 }
 
 void TrackNode::setTime(const QDateTime& time)
 {
-    Time = time.toTime_t();
+    Time = time.toSecsSinceEpoch();
 }
 
 void TrackNode::setTime(uint epoch)
@@ -515,45 +515,45 @@ TrackNode * TrackNode::fromGPX(Document* d, Layer* L, QXmlStreamReader& stream)
             Pt->setLastUpdated(Feature::OSMServer);
     }
 
-    if (stream.name() == "wpt")
+    if (stream.name() == QStringLiteral("wpt"))
         Pt->setTag("_waypoint_", "yes");
 
     QDateTime time = QDateTime::currentDateTime();
     stream.readNext();
     while(!stream.atEnd() && !stream.isEndElement()) {
-        if (stream.name() == "time") {
+        if (stream.name() == QStringLiteral("time")) {
             stream.readNext();
             QString dtm = stream.text().toString();
             time = QDateTime::fromString(dtm.left(19), Qt::ISODate);
             stream.readNext();
-        } else if (stream.name() == "ele") {
+        } else if (stream.name() == QStringLiteral("ele")) {
             stream.readNext();
             Pt->setElevation(stream.text().toString().toFloat());
             stream.readNext();
-        } else if (stream.name() == "speed") {
+        } else if (stream.name() == QStringLiteral("speed")) {
             stream.readNext();
             Pt->setSpeed(stream.text().toString().toFloat());
             stream.readNext();
-        } else if (stream.name() == "name") {
+        } else if (stream.name() == QStringLiteral("name")) {
             stream.readNext();
             Pt->setTag("name", stream.text().toString());
             stream.readNext();
-        } else if (stream.name() == "cmt") {
+        } else if (stream.name() == QStringLiteral("cmt")) {
             stream.readNext();
             Pt->setTag("_comment_", stream.text().toString());
             stream.readNext();
-        } else if (stream.name() == "desc") {
+        } else if (stream.name() == QStringLiteral("desc")) {
             stream.readNext();
             Pt->setTag("_description_", stream.text().toString());
             stream.readNext();
         }
-        else if (stream.name() == "cmt")
+        else if (stream.name() == QStringLiteral("cmt"))
         {
             stream.readNext();
             Pt->setTag("_comment_", stream.text().toString());
             stream.readNext();
         }
-        else if (stream.name() == "extensions") // for OpenStreetBugs
+        else if (stream.name() == QStringLiteral("extensions")) // for OpenStreetBugs
         {
             QString str = stream.readElementText(QXmlStreamReader::IncludeChildElements);
             QDomDocument doc;
@@ -725,7 +725,7 @@ void PhotoNode::drawHover(QPainter& thePainter, MapView* theView)
     Feature::drawHover(thePainter, theView);
 
     /* and then the image */
-    if (TEST_RFLAGS(RendererOptions::PhotosVisible) && theView->pixelPerM() > M_PREFS->getRegionalZoom()) {
+    if (TEST_RFLAGS_NODE(RendererOptions::PhotosVisible) && theView->pixelPerM() > M_PREFS->getRegionalZoom()) {
         QPoint me(theView->toView(this));
 
         qreal rt = qBound(0.2, (double)theView->pixelPerM(), 1.0);
@@ -746,7 +746,7 @@ qreal PhotoNode::pixelDistance(const QPointF& Target, qreal ClearDistance, const
 {
 #ifdef GEOIMAGE
     QPoint me = theView->toView(const_cast<PhotoNode*>(this));
-    if (TEST_RFLAGS(RendererOptions::PhotosVisible) && theView->pixelPerM() > M_PREFS->getRegionalZoom()) {
+    if (TEST_RFLAGS_NODE(RendererOptions::PhotosVisible) && theView->pixelPerM() > M_PREFS->getRegionalZoom()) {
         qreal rt = qBound(0.2, (double)theView->pixelPerM(), 1.0);
         qreal phRt = 1. * Photo->width() / Photo->height();
         QPoint phPt;
